@@ -19,7 +19,7 @@ use Try::Tiny;
 use strict;
 use warnings;
 
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 sub default_conf_names { ( 'tidyall.ini', '.tidyallrc' ) }
 
@@ -50,6 +50,8 @@ has 'base_sig'         => ( is => 'lazy', init_arg => undef );
 has 'plugin_objects'   => ( is => 'lazy', init_arg => undef );
 has 'plugins_for_mode' => ( is => 'lazy', init_arg => undef );
 
+with 'Code::TidyAll::Role::Tempdir';
+
 sub _build_backup_dir {
     my $self = shift;
     return $self->data_dir . "/backups";
@@ -490,12 +492,6 @@ sub _sig {
     return sha1_hex( join( ",", @$data ) );
 }
 
-sub _tempdir {
-    my ($self) = @_;
-    $self->{tempdir} ||= tempdir_simple();
-    return $self->{tempdir};
-}
-
 sub msg {
     my ( $self, $format, @params ) = @_;
     $self->msg_outputter()->( $format, @params );
@@ -534,7 +530,7 @@ Code::TidyAll - Engine for tidyall, your all-in-one code tidier and validator
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -615,6 +611,11 @@ by default.
 
 =item check_only
 
+=item no_cleanup
+
+A boolean indicating if we should skip cleaning temporary files or not.
+Defaults to false.
+
 =item data_dir
 
 =item iterations
